==> eiffelstudio-16.05.tar: F_code/C5/fo221.c <==
/*
 * Code for class FORMAT_DOUBLE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "fo221.h"
#include <math.h>
#include "eif_out.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {FORMAT_DOUBLE}.make */
void F242_3236 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	F81_1935(Current, arg1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_) = (EIF_INTEGER_32) arg2;
	*(EIF_CHARACTER_8 *)(Current+ _CHROFF_1_2_) = (EIF_CHARACTER_8) (EIF_CHARACTER_8) '.';
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_7_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {FORMAT_DOUBLE}.formatted */
EIF_REFERENCE F242_3254 (EIF_REFERENCE Current, EIF_REAL_64 arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REAL_64 loc2 = (EIF_REAL_64) 0;
	EIF_REAL_64 loc3 = (EIF_REAL_64) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REAL_64 loc6 = (EIF_REAL_64) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REAL_64 tr8_1;
	EIF_REAL_64 tr8_2;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,loc4);
	RTLR(2,tr1);
	RTLR(3,loc5);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	loc6 = (EIF_REAL_64) arg1;
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) 0L));
	if ((EIF_BOOLEAN) (arg1 < tr8_1)) {
		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
		loc6 = (EIF_REAL_64) (EIF_REAL_64) -loc6;
	}
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) 5L));
	tr8_2 = (EIF_REAL_64) (((EIF_INTEGER_32) ((EIF_INTEGER_32) -*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_) - ((EIF_INTEGER_32) 1L))));
	loc6 += (EIF_REAL_64) (tr8_1 * (EIF_REAL_64) pow ((EIF_REAL_64) (((EIF_INTEGER_32) 10L)), (EIF_REAL_64) (tr8_2)));
	loc2 = (EIF_REAL_64) floor((double) loc6);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_);
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) (ti4_1 + ((EIF_INTEGER_32) 1L))));
	loc3 = (EIF_REAL_64) floor((double) (EIF_REAL_64) ((EIF_REAL_64) (loc6 - loc2) * (EIF_REAL_64) pow ((EIF_REAL_64) (((EIF_INTEGER_32) 10L)), (EIF_REAL_64) (tr8_1))));
	if ((EIF_BOOLEAN) !F81_1952(Current)) {
		tr1 = c_outr64(loc2);
		loc4 = F81_1992(Current, tr1);
		if (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_5_)) {
			tr1 = F242_3255(Current, loc3);
			loc5 = F242_3256(Current, tr1);
		} else {
			loc5 = F242_3255(Current, loc3);
		}
	} else {
		loc4 = c_outr64(loc2);
		loc5 = F242_3255(Current, loc3);
	}
	tr1 = RTLNS(eif_new_type(952, 0x00).id, 952, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F947_7782(RTCW(tr1), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_0_));
	Result = (EIF_REFERENCE) tr1;
	tb1 = '\01';
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) 0L));
	if (!(EIF_BOOLEAN)(loc2 != tr8_1)) {
		tb1 = (EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_6_);
	}
	if (tb1) {
		F953_8072(RTCW(Result), loc4);
	}
	tb1 = F947_7815(RTCW(Result), (EIF_CHARACTER_8) 'e');
	if ((EIF_BOOLEAN) !tb1) {
		F953_8087(RTCW(Result), *(EIF_CHARACTER_8 *)(Current+ _CHROFF_1_2_));
		if ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_) > ((EIF_INTEGER_32) 0L))) {
			F953_8072(RTCW(Result), loc5);
		}
		if ((EIF_BOOLEAN) !F81_1951(Current)) {
			Result = F81_1993(Current, Result, loc1);
		}
	}
	tb1 = '\0';
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_1_) != ((EIF_INTEGER_32) 0L))) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
		tb1 = (EIF_BOOLEAN) (ti4_1 < *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_0_));
	}
	if (tb1) {
		RTLE;
		return (EIF_REFERENCE) F81_1996(Current, Result);
	}
	RTLE;
	return Result;
}

/* {FORMAT_DOUBLE}.pad_fraction */
EIF_REFERENCE F242_3255 (EIF_REFERENCE Current, EIF_REAL_64 arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_CHARACTER_8 tc1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Result);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	Result = c_outr64(arg1);
	F953_8095(RTCW(Result), ((EIF_INTEGER_32) 1L));
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
	if ((EIF_BOOLEAN) (ti4_1 > *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_))) {
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_);
		Result = F953_8118(RTCW(Result), ((EIF_INTEGER_32) 1L), ti4_1);
	} else {
		for (;;) {
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
			if ((EIF_BOOLEAN)(ti4_1 == *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_))) break;
			F953_8061(RTCW(Result), (EIF_CHARACTER_8) '0');
		}
	}
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_7_)) {
		loc1 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
		for (;;) {
			tb1 = '\01';
			if (!(EIF_BOOLEAN) (loc1 <= ((EIF_INTEGER_32) 1L))) {
				tc1 = F953_8037(RTCW(Result), loc1);
				tb1 = (EIF_BOOLEAN)(tc1 != (EIF_CHARACTER_8) '0');
			}
			if (tb1) break;
			F953_8092(RTCW(Result), loc1);
			loc1--;
		}
	}
	RTLE;
	return Result;
}

/* {FORMAT_DOUBLE}.separate_fraction */
EIF_REFERENCE F242_3256 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_CHARACTER_8 tc1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,tr1);
	RTLR(1,Current);
	RTLR(2,Result);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTGC;
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	tr1 = RTLNS(eif_new_type(952, 0x00).id, 952, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F947_7782(RTCW(tr1), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_0_));
	Result = (EIF_REFERENCE) tr1;
	for (;;) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
		if ((EIF_BOOLEAN) (loc1 > (EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 3L)))) break;
		loc2 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
		for (;;) {
			if ((EIF_BOOLEAN)(loc2 == ((EIF_INTEGER_32) 3L))) break;
			tc1 = F953_8037(RTCW(arg1), loc1);
			F953_8087(RTCW(Result), tc1);
			loc1++;
			loc2++;
		}
		F953_8087(RTCW(Result), *(EIF_CHARACTER_8 *)(Current+ _CHROFF_1_1_));
	}
	for (;;) {
		ti4_2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
		if ((EIF_BOOLEAN) (loc1 > ti4_2)) break;
		tc1 = F953_8037(RTCW(arg1), loc1);
		F953_8087(RTCW(Result), tc1);
		loc1++;
	}
	RTLE;
	return Result;
}

void EIF_Minit221 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.11.10.2592.tar: F_code/C5/fo221.c <==
/*
 * Code for class FORMAT_DOUBLE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "fo221.h"
#include <math.h>
#include "eif_out.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {FORMAT_DOUBLE}.make */
void F242_3627 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("make", 241, Current, 0, 2, 3675);
	RTGC;
	RTHOOK(3);
	F83_2044(Current, arg1);
	RTHOOK(4);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_) = (EIF_INTEGER_32) arg2;
	RTHOOK(5);
	*(EIF_CHARACTER_8 *)(Current+ _CHROFF_1_2_) = (EIF_CHARACTER_8) (EIF_CHARACTER_8) '.';
	RTHOOK(6);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_7_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(16);
	RTLE;
	RTEE;
}

/* {FORMAT_DOUBLE}.formatted */
EIF_REFERENCE F242_3645 (EIF_REFERENCE Current, EIF_REAL_64 arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REAL_64 loc2 = (EIF_REAL_64) 0;
	EIF_REAL_64 loc3 = (EIF_REAL_64) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REAL_64 loc6 = (EIF_REAL_64) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REAL_64 tr8_1;
	EIF_REAL_64 tr8_2;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,loc4);
	RTLR(2,tr1);
	RTLR(3,loc5);
	RTLR(4,Result);
	RTLIU(5);
	
	RTEAA("formatted", 241, Current, 6, 1, 3693);
	RTGC;
	RTHOOK(1);
	loc6 = (EIF_REAL_64) arg1;
	RTHOOK(2);
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(3);
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) 0L));
	if ((EIF_BOOLEAN) (arg1 < tr8_1)) {
		RTHOOK(4);
		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
		RTHOOK(5);
		loc6 = (EIF_REAL_64) (EIF_REAL_64) -loc6;
	}
	RTHOOK(6);
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) 5L));
	tr8_2 = (EIF_REAL_64) (((EIF_INTEGER_32) ((EIF_INTEGER_32) -*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_) - ((EIF_INTEGER_32) 1L))));
	loc6 += (EIF_REAL_64) (tr8_1 * (EIF_REAL_64) pow ((EIF_REAL_64) (((EIF_INTEGER_32) 10L)), (EIF_REAL_64) (tr8_2)));
	RTHOOK(7);
	loc2 = (EIF_REAL_64) floor((double) loc6);
	RTHOOK(8);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_);
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) (ti4_1 + ((EIF_INTEGER_32) 1L))));
	loc3 = (EIF_REAL_64) floor((double) (EIF_REAL_64) ((EIF_REAL_64) (loc6 - loc2) * (EIF_REAL_64) pow ((EIF_REAL_64) (((EIF_INTEGER_32) 10L)), (EIF_REAL_64) (tr8_1))));
	RTHOOK(9);
	if ((EIF_BOOLEAN) !F83_2061(Current)) {
		RTHOOK(10);
		tr1 = c_outr64(loc2);
		loc4 = F83_2101(Current, tr1);
		RTHOOK(11);
		if (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_5_)) {
			RTHOOK(12);
			tr1 = F242_3646(Current, loc3);
			loc5 = F242_3647(Current, tr1);
		} else {
			RTHOOK(13);
			loc5 = F242_3646(Current, loc3);
		}
	} else {
		RTHOOK(14);
		loc4 = c_outr64(loc2);
		RTHOOK(15);
		loc5 = F242_3646(Current, loc3);
	}
	RTHOOK(16);
	tr1 = RTLNS(eif_new_type(1029, 0x00).id, 1029, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1028_8697(RTCW(tr1), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_0_));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(17);
	tb1 = '\01';
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) 0L));
	if (!(EIF_BOOLEAN)(loc2 != tr8_1)) {
		tb1 = (EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_6_);
	}
	if (tb1) {
		RTHOOK(18);
		F1030_8808(RTCW(Result), loc4);
	}
	RTHOOK(19);
	tb1 = F1028_8731(RTCW(Result), (EIF_CHARACTER_8) 'e');
	if ((EIF_BOOLEAN) !tb1) {
		RTHOOK(20);
		F1030_8823(RTCW(Result), *(EIF_CHARACTER_8 *)(Current+ _CHROFF_1_2_));
		RTHOOK(21);
		if ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_) > ((EIF_INTEGER_32) 0L))) {
			RTHOOK(22);
			F1030_8808(RTCW(Result), loc5);
		}
		RTHOOK(23);
		if ((EIF_BOOLEAN) !F83_2060(Current)) {
			RTHOOK(24);
			Result = F83_2102(Current, Result, loc1);
		}
	}
	RTHOOK(25);
	tb1 = '\0';
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_1_) != ((EIF_INTEGER_32) 0L))) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
		tb1 = (EIF_BOOLEAN) (ti4_1 < *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_0_));
	}
	if (tb1) {
		RTHOOK(26);
		RTHOOK(27);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) F83_2105(Current, Result);
	}
	RTHOOK(30);
	RTLE;
	RTEE;
	return Result;
}

/* {FORMAT_DOUBLE}.pad_fraction */
EIF_REFERENCE F242_3646 (EIF_REFERENCE Current, EIF_REAL_64 arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_CHARACTER_8 tc1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Result);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("pad_fraction", 241, Current, 1, 1, 3694);
	RTGC;
	RTHOOK(1);
	Result = c_outr64(arg1);
	RTHOOK(2);
	F1030_8831(RTCW(Result), ((EIF_INTEGER_32) 1L));
	RTHOOK(3);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
	if ((EIF_BOOLEAN) (ti4_1 > *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_))) {
		RTHOOK(4);
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_);
		Result = F1030_8854(RTCW(Result), ((EIF_INTEGER_32) 1L), ti4_1);
	} else {
		for (;;) {
			RTHOOK(5);
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
			if ((EIF_BOOLEAN)(ti4_1 == *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_3_))) break;
			RTHOOK(6);
			F1030_8797(RTCW(Result), (EIF_CHARACTER_8) '0');
		}
	}
	RTHOOK(7);
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_7_)) {
		RTHOOK(8);
		loc1 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
		for (;;) {
			RTHOOK(9);
			tb1 = '\01';
			if (!(EIF_BOOLEAN) (loc1 <= ((EIF_INTEGER_32) 1L))) {
				tc1 = F1030_8773(RTCW(Result), loc1);
				tb1 = (EIF_BOOLEAN)(tc1 != (EIF_CHARACTER_8) '0');
			}
			if (tb1) break;
			RTHOOK(10);
			F1030_8828(RTCW(Result), loc1);
			RTHOOK(11);
			loc1--;
		}
	}
	RTHOOK(13);
	RTLE;
	RTEE;
	return Result;
}

/* {FORMAT_DOUBLE}.separate_fraction */
EIF_REFERENCE F242_3647 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_CHARACTER_8 tc1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,tr1);
	RTLR(1,Current);
	RTLR(2,Result);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTEAA("separate_fraction", 241, Current, 2, 1, 3695);
	RTGC;
	RTHOOK(2);
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(3);
	tr1 = RTLNS(eif_new_type(1029, 0x00).id, 1029, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1028_8697(RTCW(tr1), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_8_0_0_));
	Result = (EIF_REFERENCE) tr1;
	for (;;) {
		RTHOOK(4);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
		if ((EIF_BOOLEAN) (loc1 > (EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 3L)))) break;
		RTHOOK(5);
		loc2 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
		for (;;) {
			RTHOOK(6);
			if ((EIF_BOOLEAN)(loc2 == ((EIF_INTEGER_32) 3L))) break;
			RTHOOK(7);
			tc1 = F1030_8773(RTCW(arg1), loc1);
			F1030_8823(RTCW(Result), tc1);
			RTHOOK(8);
			loc1++;
			RTHOOK(9);
			loc2++;
		}
		RTHOOK(10);
		F1030_8823(RTCW(Result), *(EIF_CHARACTER_8 *)(Current+ _CHROFF_1_1_));
	}
	for (;;) {
		RTHOOK(11);
		ti4_2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
		if ((EIF_BOOLEAN) (loc1 > ti4_2)) break;
		RTHOOK(12);
		tc1 = F1030_8773(RTCW(arg1), loc1);
		F1030_8823(RTCW(Result), tc1);
		RTHOOK(13);
		loc1++;
	}
	RTHOOK(14);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit221 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
